@@ -27,7 +27,7 @@
 #
 #========================================================================
 #
-# Version 4.2.1, released 7 May 2018.
+# Version 4.3.0, released 25 Nov 2018.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -71,7 +71,7 @@ sub action
             $EmailStr{$info->{$host}{lastTime}} .= <<EOF;
 <tr><td>${UserLink($u)} </td>
     <td>${HostLink($host)} </td>
-    <td>$emailTimeStr </td>
+    <td data-date_format="$Conf{CgiDateFormatMMDD}">$emailTimeStr </td>
     <td>$info->{$host}{lastSubj} </td></tr>
 EOF
         }
