@@ -94,6 +94,9 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
         <li>L\'espace de stockage a t rcemment rempli  \$Info{DUlastValue}%
             (\$DUlastTime), le maximum aujourd\'hui a t de \$Info{DUDailyMax}% (\$DUmaxTime)
             et hier le maximum tait de \$Info{DUDailyMaxPrev}%.
+        <li>Inode L\'espace de stockage a t rcemment rempli  \$Info{DUInodelastValue}%
+            (\$DUlastTime), le maximum aujourd\'hui a t de \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+            et hier le maximum tait de \$Info{DUInodeDailyMaxPrev}%.
     </ul>
 </ul>
 EOF
@@ -104,7 +107,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 <p>
 \${h2("Travaux en cours d'excution")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td> Hte </td>
     <td> Type </td>
     <td> Utilisateur </td>
@@ -123,7 +126,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 
 \${h2("checs qui demandent de l'attention")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Hte </td>
     <td align="center"> Type </td>
     <td align="center"> Utilisateur </td>
@@ -147,6 +150,9 @@ $Lang{BackupPC_Summary}=<<EOF;
 <li>L\'espace de stockage a t rcemment rempli  \$Info{DUlastValue}%
     (\$DUlastTime), le maximum aujourd\'hui a t de \$Info{DUDailyMax}% (\$DUmaxTime)
     et hier le maximum tait de \$Info{DUDailyMaxPrev}%.
+<li>Inode L\'espace de stockage a t rcemment rempli  \$Info{DUInodelastValue}%
+    (\$DUlastTime), le maximum aujourd\'hui a t de \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+    et hier le maximum tait de \$Info{DUInodeDailyMaxPrev}%.
 </ul>
 </p>
 
@@ -377,8 +383,9 @@ $Lang{Backup_Queue_Summary} = <<EOF;
 <p>
 Les demandes utilisateurs suivantes sont actuellement en attente :
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Hte </td>
+    <td> Action </td>
     <td> Temps Requis </td>
     <td> Utilisateur </td></tr>
 \$strUser
@@ -388,8 +395,9 @@ Les demandes utilisateurs suivantes sont actuellement en attente :
 <p>
 Les demandes en arrire plan suivantes sont actuellement en attente :
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Hte </td>
+    <td> Action </td>
     <td> Temps requis </td>
     <td> Utilisateur </td></tr>
 \$strBg
@@ -398,8 +406,9 @@ Les demandes en arrire plan suivantes sont actuellement en attente :
 <p>
 Les demandes de commande suivantes sont actuellement en attente :
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Htes </td>
+    <td> Action </td>
     <td> Temps Requis </td>
     <td> Utilisateur </td>
     <td> Commande </td></tr>
@@ -428,7 +437,7 @@ $Lang{BackupPC__Log_File_History} = "BackupPC: Historique du fichier journal";
 $Lang{Log_File_History__hdr} = <<EOF;
 \${h1("Historique du fichier journal \$hdr")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Fichier </td>
     <td align="center"> Taille </td>
     <td align="center"> Date de modification </td></tr>
@@ -440,7 +449,7 @@ EOF
 $Lang{Recent_Email_Summary} = <<EOF;
 \${h1("Rsum des courriels rcents (du plus rcent au plus vieux)")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Destinataire </td>
     <td align="center"> Hte </td>
     <td align="center"> Date </td>
@@ -702,7 +711,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 <p>
 Cliquer sur le numro de l\'archive pour naviguer et restaurer les fichiers de sauvegarde.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Sauvegarde n </td>
     <td align="center"> Type </td>
     <td align="center"> Fusionne </td> 
@@ -710,7 +719,7 @@ Cliquer sur le numro de l\'archive pour naviguer et restaurer les fichiers de sa
     <td align="center"> Date de dmarrage </td>
     <td align="center"> Dure (min) </td>
     <td align="center"> ge (jours) </td>
-    <td align="center"> </td>
+    \$deleteHdrStr
     <td align="center"> Chemin d\'accs de la sauvegarde sur le serveur </td>
 </tr>
 \$str
@@ -720,7 +729,7 @@ Cliquer sur le numro de l\'archive pour naviguer et restaurer les fichiers de sa
 \$restoreStr
 </p>
 \${h2("Rsum des erreurs de transfert")}
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Sauvegarde n </td>
     <td align="center"> Type </td>
     <td align="center"> Voir </td>
@@ -738,13 +747,13 @@ Les fichiers existants sont ceux qui sont dj sur le serveur;
 Les nouveaux fichiers sont ceux qui ont t ajouts au serveur.
 Les fichiers vides et les erreurs de SMB ne sont pas comptabiliss dans les fichiers nouveaux ou rutiliss.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="2" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Totaux </td>
     <td align="center" colspan="2"> Fichiers existants </td>
     <td align="center" colspan="2"> Nouveaux fichiers </td>
 </tr>
-<tr class="tableheader">
+<tr class="tableheader sortheader">
     <td align="center"> Sauvegarde n </td>
     <td align="center"> Type </td>
     <td align="center"> Nb de Fichiers </td>
@@ -763,12 +772,12 @@ Les fichiers vides et les erreurs de SMB ne sont pas comptabiliss dans les fichi
 Performance de la compression pour les fichiers dj sur le serveur et
 rcemment compresss.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="3" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Fichiers existants </td>
     <td align="center" colspan="3"> Nouveaux fichiers </td>
 </tr>
-<tr class="tableheader"><td align="center"> Nb de sauvegardes </td>
+<tr class="tableheader sortheader"><td align="center"> Nb de sauvegardes </td>
     <td align="center"> Type </td>
     <td align="center"> Niveau de Compression </td>
     <td align="center"> Taille (Mo) </td>
@@ -1214,7 +1223,7 @@ $Lang{Restore_Summary} = <<EOF;
 \${h2("Rsum de la restauration")}
 <p>
 Cliquer sur le numro de restauration pour plus de dtails.
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Sauvegarde n </td>
     <td align="center"> Rsultat </td>
     <td align="right"> Date de dpart</td>
@@ -1320,7 +1329,7 @@ ordinateur est correctement connect au rseau.
 
 Merci de votre attention,
 BackupPC Gnie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # No recent backup
@@ -1351,7 +1360,7 @@ avec votre ordinateur.
 
 Merci de votre attention,
 BackupPC Gnie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # Old Outlook files
@@ -1383,7 +1392,7 @@ sauvegarde devrait prendre quelques minutes  s'effectuer.
 
 Merci de votre attention,
 BackupPC Gnie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 $Lang{howLong_not_been_backed_up} = "jamais t sauvegards";
@@ -1402,6 +1411,7 @@ Vitesse (Mo/s) : \$fullRate;
 Nb incrmentielles : \$incrCnt;
 Incrmentielles ge (jours) : \$incrAge;
 tat actuel : \$host_state;
+Dsactive: \$host_disabled;
 Dernire tentative : \$host_last_attempt;
 EOF
 
