@@ -97,6 +97,9 @@ $Lang{BackupPC_Server_Status_General_Info}= <<EOF;
         <li>Файлова система пула зайнята на \$Info{DUlastValue}%
             (\$DUlastTime), сьогодняшній максимум \$Info{DUDailyMax}% (\$DUmaxTime)
             вчорашній максимум \$Info{DUDailyMaxPrev}%.
+        <li>Inode Файлова система пула зайнята на \$Info{DUInodelastValue}%
+            (\$DUlastTime), сьогодняшній максимум \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+            вчорашній максимум \$Info{DUInodeDailyMaxPrev}%.
     </ul>
 </ul>
 EOF
@@ -107,7 +110,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 <p>
 \${h2("Запущені зараз завдання")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td> Хост </td>
     <td> Тип </td>
     <td> Користувач </td>
@@ -126,7 +129,7 @@ $Lang{BackupPC_Server_Status} = <<EOF;
 
 \${h2("Помилки, що потребують уваги")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Хост </td>
     <td align="center"> Тип </td>
     <td align="center"> Користувач </td>
@@ -150,6 +153,9 @@ $Lang{BackupPC_Summary} = <<EOF;
 <li>Файлова система пула зайнята на \$Info{DUlastValue}%
     (\$DUlastTime), сьогодняшній максимум \$Info{DUDailyMax}% (\$DUmaxTime)
         вчорашній максимум \$Info{DUDailyMaxPrev}%.
+<li>Inode Файлова система пула зайнята на \$Info{DUInodelastValue}%
+    (\$DUlastTime), сьогодняшній максимум \$Info{DUInodeDailyMax}% (\$DUInodemaxTime)
+    вчорашній максимум \$Info{DUInodeDailyMaxPrev}%.
 </ul>
 </p>
 
@@ -380,8 +386,9 @@ $Lang{Backup_Queue_Summary} = <<EOF;
 <p>
 Наступні запити користувачів поставлені до черги:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Хост </td>
+    <td> Action </td>
     <td> Час запиту </td>
     <td> Користувач </td></tr>
 \$strUser
@@ -391,8 +398,9 @@ $Lang{Backup_Queue_Summary} = <<EOF;
 <p>
 Наступні фонові запити були поставлені до черги:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Хост </td>
+    <td> Action </td>
     <td> Час запиту </td>
     <td> Користувач </td></tr>
 \$strBg
@@ -401,8 +409,9 @@ $Lang{Backup_Queue_Summary} = <<EOF;
 <p>
 Наступні команди були поставлені до черги:
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td> Хост </td>
+    <td> Action </td>
     <td> Час запиту </td>
     <td> Користувач </td>
     <td> Команда </td></tr>
@@ -431,7 +440,7 @@ $Lang{BackupPC__Log_File_History} = "BackupPC: Історія лог-файлу"
 $Lang{Log_File_History__hdr} = <<EOF;
 \${h1("Історія лог-файлу \$hdr")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Файл </td>
     <td align="center"> Розмір </td>
     <td align="center"> Час зміни </td></tr>
@@ -443,7 +452,7 @@ EOF
 $Lang{Recent_Email_Summary} = <<EOF;
 \${h1("Останні поштові відправлення (В зворотньому порядку)")}
 <p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Отримувач </td>
     <td align="center"> Хост </td>
     <td align="center"> Час </td>
@@ -705,7 +714,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 <p>
 Натисніть на номер резервної копії для огляду та відновлення файлів з неї.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3">
 <tr class="tableheader"><td align="center"> Рез. Копія# </td>
     <td align="center"> тип </td>
     <td align="center"> Повний </td>
@@ -723,7 +732,7 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 \$restoreStr
 </p>
 \${h2("Зведена інформація про помилки Xfer")}
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Backup# </td>
     <td align="center"> Тип </td>
     <td align="center"> Журнал </td>
@@ -741,13 +750,13 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 що тільки-но додаються до пулу.
 Пусті файли та SMB-помилки не враховуються
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="2" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Totals </td>
     <td align="center" colspan="2"> Existing Files </td>
     <td align="center" colspan="2"> New Files </td>
 </tr>
-<tr class="tableheader">
+<tr class="tableheader sortheader">
     <td align="center"> Рез. копія# </td>
     <td align="center"> Тип </td>
     <td align="center"> #Файли </td>
@@ -765,12 +774,12 @@ $Lang{Host__host_Backup_Summary2} = <<EOF;
 <p>
 Рівень стискання нових та існуючих файлів.
 </p>
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td colspan="3" bgcolor="#ffffff"></td>
     <td align="center" colspan="3"> Існуючі файли </td>
     <td align="center" colspan="3"> Нові файли </td>
 </tr>
-<tr class="tableheader"><td align="center"> Рез. копія# </td>
+<tr class="tableheader sortheader"><td align="center"> Рез. копія# </td>
     <td align="center"> Тип </td>
     <td align="center"> Рівень стиск. </td>
     <td align="center"> Розмір/MB </td>
@@ -1216,7 +1225,7 @@ $Lang{Restore_Summary} = <<EOF;
 \${h2("Інформація про відновлення")}
 <p>
 Натисніть на номер для перегляду деталей.
-<table class="tableStnd" border cellspacing="1" cellpadding="3" width="80%">
+<table class="tableStnd sortable" border cellspacing="1" cellpadding="3" width="80%">
 <tr class="tableheader"><td align="center"> Відновлення# </td>
     <td align="center"> Результат </td>
     <td align="right"> Дата початку</td>
@@ -1322,7 +1331,7 @@ next time you are in the office.
 
 Regards,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # No recent backup
@@ -1351,7 +1360,7 @@ attachments) cannot be restored if your PC disk crashes.
 
 Regards,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 # Old Outlook files
@@ -1382,7 +1391,7 @@ complete.
 
 Regards,
 BackupPC Genie
-http://backuppc.sourceforge.net
+https://backuppc.github.io/backuppc
 EOF
 
 $Lang{howLong_not_been_backed_up} = "not been backed up successfully";
@@ -1401,6 +1410,7 @@ Speed MB/sec: \$fullRate;
 Incr Count: \$incrCnt;
 Incr Age/Days: \$incrAge;
 State: \$host_state;
+Disabled: \$host_disabled;
 Last Attempt: \$host_last_attempt;
 EOF
 
