@@ -30,7 +30,7 @@
 #
 #========================================================================
 #
-# Version 4.2.0, released 8 Apr 2018.
+# Version 4.3.0, released 25 Nov 2018.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -259,6 +259,7 @@ sub dirCache
                             || $file eq ".."
                             || $file eq "."
                             || $file eq "backupInfo"
+                            || $file eq "refCnt"
                             || $mangle && $file =~ /^attrib/ );
 
                     if ( defined($attr) && defined(my $a = $attr->get($fileUM)) ) {
@@ -476,6 +477,7 @@ sub shareList
                    || $file eq ".."
                    || $file eq "backupInfo"
                    || $file eq "inode"
+                   || $file eq "refCnt"
                 );
             my $fileUM = $file;
             $fileUM = $m->{bpc}->fileNameUnmangle($fileUM) if ( $mangle );
